@@ -75,6 +75,13 @@ public interface VolumeOrchestrationService {
         true
     );
 
+    ConfigKey<Long> MaxVolumeSize = new ConfigKey<Long>("Storage",
+            Long.class,
+            "storage.max.volume.size",
+            "2000",
+            "The maximum size for a volume (in GB).",
+            true);
+
     VolumeInfo moveVolume(VolumeInfo volume, long destPoolDcId, Long destPoolPodId, Long destPoolClusterId, HypervisorType dataDiskHyperType)
         throws ConcurrentOperationException, StorageUnavailableException;
 
