@@ -141,6 +141,15 @@ public class TemplateObject implements TemplateInfo {
         return image.getSize();
     }
 
+    @Override
+    public long getPhysicalSize() {
+        TemplateDataStoreVO templateDataStoreVO = templateStoreDao.findByTemplate(imageVO.getId(), DataStoreRole.Image);
+        if (templateDataStoreVO != null) {
+            return templateDataStoreVO.getPhysicalSize();
+        }
+        return imageVO.getSize();
+    }
+
     @Override
     public DataObjectType getType() {
         return DataObjectType.TEMPLATE;
