@@ -916,8 +916,9 @@ public class XenServerStorageProcessor implements StorageProcessor {
             try {
                 final NfsTO nfsStore = (NfsTO) destStore;
                 final URI uri = new URI(nfsStore.getUrl());
+                final String nfsVersion = nfsStore.getNfsVersion();
                 // Create the volume folder
-                if (!hypervisorResource.createSecondaryStorageFolder(conn, uri.getHost() + ":" + uri.getPath(), destVolume.getPath())) {
+                if (!hypervisorResource.createSecondaryStorageFolder(conn, uri.getHost() + ":" + uri.getPath(), destVolume.getPath(), nfsVersion)) {
                     throw new InternalErrorException("Failed to create the volume folder.");
                 }
 
@@ -1179,6 +1180,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             secondaryStorageUrl = cacheStore.getUrl();
             destPath = destData.getPath();
         }
+        String nfsVersion = cacheStore.getNfsVersion();
 
         final SnapshotObjectTO snapshotTO = (SnapshotObjectTO) srcData;
         final SnapshotObjectTO snapshotOnImage = (SnapshotObjectTO) destData;
@@ -1235,7 +1237,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             if (fullbackup) {
                 // the first snapshot is always a full snapshot
 
-                if (!hypervisorResource.createSecondaryStorageFolder(conn, secondaryStorageMountPath, folder)) {
+                if (!hypervisorResource.createSecondaryStorageFolder(conn, secondaryStorageMountPath, folder, nfsVersion)) {
                     details = " Filed to create folder " + folder + " in secondary storage";
                     s_logger.warn(details);
                     return new CopyCmdAnswer(details);
@@ -1349,6 +1351,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
         final TemplateObjectTO template = (TemplateObjectTO) cmd.getDestTO();
         final NfsTO destStore = (NfsTO) cmd.getDestTO().getDataStore();
         final int wait = cmd.getWait();
+        final String nfsVersion = destStore.getNfsVersion();
 
         final String secondaryStoragePoolURL = destStore.getUrl();
         final String volumeUUID = volume.getPath();
@@ -1364,7 +1367,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             final URI uri = new URI(secondaryStoragePoolURL);
             secondaryStorageMountPath = uri.getHost() + ":" + uri.getPath();
             installPath = template.getPath();
-            if (!hypervisorResource.createSecondaryStorageFolder(conn, secondaryStorageMountPath, installPath)) {
+            if (!hypervisorResource.createSecondaryStorageFolder(conn, secondaryStorageMountPath, installPath, nfsVersion)) {
                 details = " Filed to create folder " + installPath + " in secondary storage";
                 s_logger.warn(details);
                 return new CopyCmdAnswer(details);
@@ -1391,7 +1394,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             final String templatePath = secondaryStorageMountPath + "/" + installPath;
             result =
                     hypervisorResource.postCreatePrivateTemplate(conn, templatePath, tmpltFilename, tmpltUUID, userSpecifiedName, null, physicalSize, virtualSize,
-                            template.getId());
+                            template.getId(), nfsVersion);
             if (!result) {
                 throw new CloudRuntimeException("Could not create the template.properties file on secondary storage dir: " + tmpltURI);
             }
@@ -1411,7 +1414,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
                 hypervisorResource.removeSR(conn, tmpltSR);
             }
             if (secondaryStorageMountPath != null) {
-                hypervisorResource.deleteSecondaryStorageFolder(conn, secondaryStorageMountPath, installPath);
+                hypervisorResource.deleteSecondaryStorageFolder(conn, secondaryStorageMountPath, installPath, nfsVersion);
             }
             details = "Creating template from volume " + volumeUUID + " failed due to " + e.toString();
             s_logger.error(details, e);
@@ -1465,7 +1468,8 @@ public class XenServerStorageProcessor implements StorageProcessor {
 
             final String destNfsPath = destUri.getHost() + ":" + destUri.getPath();
 
-            if (!hypervisorResource.createSecondaryStorageFolder(conn, destNfsPath, destDir)) {
+            String destNfsVersion = destStore.getNfsVersion();
+            if (!hypervisorResource.createSecondaryStorageFolder(conn, destNfsPath, destDir, destNfsVersion)) {
                 final String details = " Failed to create folder " + destDir + " in secondary storage";
 
                 s_logger.warn(details);
@@ -1500,7 +1504,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             templatePath = templatePath.replaceAll("//", "/");
 
             result = hypervisorResource.postCreatePrivateTemplate(conn, templatePath, templateFilename, templateUuid, userSpecifiedTemplateName, null,
-                    physicalSize, virtualSize, templateObjTO.getId());
+                    physicalSize, virtualSize, templateObjTO.getId(), destNfsVersion);
 
             if (!result) {
                 throw new CloudRuntimeException("Could not create the template.properties file on secondary storage dir: " + templateUri);
