@@ -98,19 +98,18 @@ provider_conf_file="${working_dir}/provider.yaml"
 curl -sSL ${PROVIDER_URL} -o ${provider_conf_file}
 
 echo "Fetching k8s docker images..."
-docker -v
+ctr -v
 if [ $? -ne 0 ]; then
-    echo "Installing docker..."
+    echo "Installing containerd..."
     if [ -f /etc/redhat-release ]; then
       sudo yum -y remove docker-common docker container-selinux docker-selinux docker-engine
       sudo yum -y install lvm2 device-mapper device-mapper-persistent-data device-mapper-event device-mapper-libs device-mapper-event-libs
       sudo yum install -y http://mirror.centos.org/centos/7/extras/x86_64/Packages/container-selinux-2.107-3.el7.noarch.rpm
-      sudo wget https://download.docker.com/linux/centos/docker-ce.repo -O /etc/yum.repos.d/docker-ce.repo && sudo yum -y install docker-ce
-      sudo systemctl enable docker && sudo systemctl start docker
+      sudo yum install -y containerd.io
     elif [ -f /etc/lsb-release ]; then
-      sudo apt update && sudo apt install docker.io -y
-      sudo systemctl enable docker && sudo systemctl start docker
+      sudo apt update && sudo apt install containerd.io -y
     fi
+    sudo systemctl enable containerd && sudo systemctl start containerd
 fi
 mkdir -p "${working_dir}/docker"
 output=`${k8s_dir}/kubeadm config images list --kubernetes-version=${RELEASE}`
@@ -130,11 +129,14 @@ provider_image=`grep "image:" ${provider_conf_file} | cut -d ':' -f2- | tr -d '
 output=`printf "%s\n" ${output} ${provider_image}`
 
 while read -r line; do
-    echo "Downloading docker image $line ---"
-    sudo docker pull "$line"
+    echo "Downloading image $line ---"
+    if [[ $line == kubernetesui* ]] || [[ $line == apache* ]]; then
+      line="docker.io/${line}"
+    fi
+    sudo ctr image pull "$line"
     image_name=`echo "$line" | grep -oE "[^/]+$"`
-    sudo docker save "$line" > "${working_dir}/docker/$image_name.tar"
-    sudo docker image rm "$line"
+    sudo ctr image export "${working_dir}/docker/$image_name.tar" "$line"
+    sudo ctr image rm "$line"
 done <<< "$output"
 
 echo "Restore kubeadm permissions..."
