@@ -21,8 +21,11 @@ import java.util.List;
 
 import javax.inject.Inject;
 
+import org.apache.cloudstack.annotation.AnnotationService;
+import org.apache.cloudstack.annotation.dao.AnnotationDao;
 import org.apache.cloudstack.api.ResponseObject.ResponseView;
 import org.apache.cloudstack.api.response.VolumeResponse;
+import org.apache.cloudstack.context.CallContext;
 import org.apache.cloudstack.framework.config.dao.ConfigurationDao;
 import org.apache.cloudstack.storage.datastore.db.PrimaryDataStoreDao;
 import org.apache.cloudstack.storage.datastore.db.StoragePoolVO;
@@ -34,7 +37,6 @@ import com.cloud.api.ApiResponseHelper;
 import com.cloud.api.query.vo.VolumeJoinVO;
 import com.cloud.offering.ServiceOffering;
 import com.cloud.storage.Storage;
-import com.cloud.storage.VMTemplateHostVO;
 import com.cloud.storage.VMTemplateStorageResourceAssoc.Status;
 import com.cloud.storage.Volume;
 import com.cloud.user.AccountManager;
@@ -55,6 +57,8 @@ public class VolumeJoinDaoImpl extends GenericDaoBaseWithTagInformation<VolumeJo
     private VmDiskStatisticsDao vmDiskStatsDao;
     @Inject
     private PrimaryDataStoreDao primaryDataStoreDao;
+    @Inject
+    private AnnotationDao annotationDao;
 
     private final SearchBuilder<VolumeJoinVO> volSearch;
 
@@ -135,9 +139,6 @@ public class VolumeJoinDaoImpl extends GenericDaoBaseWithTagInformation<VolumeJo
             volResponse.setState(volume.getState().toString());
         }
         if (volume.getState() == Volume.State.UploadOp) {
-            // com.cloud.storage.VolumeHostVO volumeHostRef =
-            // ApiDBUtils.findVolumeHostRef(volume.getId(),
-            // volume.getDataCenterId());
             volResponse.setSize(volume.getVolumeStoreSize());
             volResponse.setCreated(volume.getCreatedOnStore());
 
@@ -145,7 +146,7 @@ public class VolumeJoinDaoImpl extends GenericDaoBaseWithTagInformation<VolumeJo
                 volResponse.setHypervisor(ApiDBUtils.getHypervisorTypeFromFormat(volume.getDataCenterId(), volume.getFormat()).toString());
             if (volume.getDownloadState() != Status.DOWNLOADED) {
                 String volumeStatus = "Processing";
-                if (volume.getDownloadState() == VMTemplateHostVO.Status.DOWNLOAD_IN_PROGRESS) {
+                if (volume.getDownloadState() == Status.DOWNLOAD_IN_PROGRESS) {
                     if (volume.getDownloadPercent() == 100) {
                         volumeStatus = "Checking Volume";
                     } else {
@@ -154,14 +155,14 @@ public class VolumeJoinDaoImpl extends GenericDaoBaseWithTagInformation<VolumeJo
                     volResponse.setState("Uploading");
                 } else {
                     volumeStatus = volume.getErrorString();
-                    if (volume.getDownloadState() == VMTemplateHostVO.Status.NOT_DOWNLOADED) {
+                    if (volume.getDownloadState() == Status.NOT_DOWNLOADED) {
                         volResponse.setState("UploadNotStarted");
                     } else {
                         volResponse.setState("UploadError");
                     }
                 }
                 volResponse.setStatus(volumeStatus);
-            } else if (volume.getDownloadState() == VMTemplateHostVO.Status.DOWNLOADED) {
+            } else if (volume.getDownloadState() == Status.DOWNLOADED) {
                 volResponse.setStatus("Upload Complete");
                 volResponse.setState("Uploaded");
             } else {
@@ -212,10 +213,13 @@ public class VolumeJoinDaoImpl extends GenericDaoBaseWithTagInformation<VolumeJo
             volResponse.setStoragePoolId(volume.getPoolUuid());
             if (poolId != null) {
                 StoragePoolVO poolVO = primaryDataStoreDao.findById(poolId);
-                if (poolVO != null && poolVO.getParent() != 0L) {
-                    StoragePoolVO datastoreClusterVO = primaryDataStoreDao.findById(poolVO.getParent());
-                    volResponse.setStoragePoolName(datastoreClusterVO.getName());
-                    volResponse.setStoragePoolId(datastoreClusterVO.getUuid());
+                if (poolVO != null) {
+                    volResponse.setStorageType(poolVO.isLocal() ? ServiceOffering.StorageType.local.toString() : ServiceOffering.StorageType.shared.toString());
+                    if (poolVO.getParent() != 0L) {
+                        StoragePoolVO datastoreClusterVO = primaryDataStoreDao.findById(poolVO.getParent());
+                        volResponse.setStoragePoolName(datastoreClusterVO.getName());
+                        volResponse.setStoragePoolId(datastoreClusterVO.getUuid());
+                    }
                 }
             }
         }
@@ -240,6 +244,9 @@ public class VolumeJoinDaoImpl extends GenericDaoBaseWithTagInformation<VolumeJo
             addTagInformation(volume, volResponse);
         }
 
+        volResponse.setHasAnnotation(annotationDao.hasAnnotations(volume.getUuid(), AnnotationService.EntityType.VOLUME.name(),
+                _accountMgr.isRootAdmin(CallContext.current().getCallingAccount().getId())));
+
         volResponse.setExtractable(isExtractable);
         volResponse.setDisplayVolume(volume.isDisplayVolume());
         volResponse.setChainInfo(volume.getChainInfo());
@@ -268,6 +275,10 @@ public class VolumeJoinDaoImpl extends GenericDaoBaseWithTagInformation<VolumeJo
         if (tag_id > 0) {
             addTagInformation(vol, volData);
         }
+        if (volData.hasAnnotation() == null) {
+            volData.setHasAnnotation(annotationDao.hasAnnotations(vol.getUuid(), AnnotationService.EntityType.VOLUME.name(),
+                    _accountMgr.isRootAdmin(CallContext.current().getCallingAccount().getId())));
+        }
         return volData;
     }
 
