@@ -108,6 +108,9 @@ public class UserVmJoinVO extends BaseViewWithTagInformationVO implements Contro
     @Column(name = GenericDao.REMOVED_COLUMN)
     private Date removed;
 
+    @Column(name="update_time")
+    private Date lastUpdated;
+
     @Column(name = "instance_name", updatable = true, nullable = false)
     private String instanceName;
 
@@ -139,6 +142,9 @@ public class UserVmJoinVO extends BaseViewWithTagInformationVO implements Contro
     @Column(name = "private_mac_address", updatable = true, nullable = true)
     private String privateMacAddress;
 
+    @Column(name = "cluster_id", updatable = true, nullable = false)
+    private Long clusterId;
+
     @Column(name = "pod_id", updatable = true, nullable = false)
     private Long podId;
 
@@ -276,6 +282,9 @@ public class UserVmJoinVO extends BaseViewWithTagInformationVO implements Contro
     @Column(name = "nic_uuid")
     private String nicUuid;
 
+    @Column(name = "nic_device_id")
+    private Integer nicDeviceId = null;
+
     @Column(name = "is_default_nic")
     private boolean isDefaultNic;
 
@@ -488,6 +497,10 @@ public class UserVmJoinVO extends BaseViewWithTagInformationVO implements Contro
         return removed;
     }
 
+    public Date getLastUpdated() {
+        return lastUpdated;
+    }
+
     public String getInstanceName() {
         return instanceName;
     }
@@ -520,6 +533,10 @@ public class UserVmJoinVO extends BaseViewWithTagInformationVO implements Contro
         return lastHostId;
     }
 
+    public Long getClusterId() {
+        return clusterId;
+    }
+
     public Long getPodId() {
         return podId;
     }
@@ -668,6 +685,10 @@ public class UserVmJoinVO extends BaseViewWithTagInformationVO implements Contro
         return nicId;
     }
 
+    public Integer getNicDeviceId() {
+        return nicDeviceId;
+    }
+
     public boolean isDefaultNic() {
         return isDefaultNic;
     }
