@@ -73,6 +73,7 @@ import com.cloud.vm.VirtualMachineManager;
 import com.cloud.vm.VirtualMachineProfile;
 
 import org.apache.cloudstack.network.topology.NetworkTopology;
+import org.apache.commons.collections.CollectionUtils;
 import org.apache.log4j.Logger;
 import org.cloud.network.router.deployment.RouterDeploymentDefinition;
 import org.cloud.network.router.deployment.RouterDeploymentDefinitionBuilder;
@@ -348,7 +349,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
 
         //1st time it runs the domain router of the VM shall be returned
         List<DomainRouterVO> routers = super.getRouters(network, dest);
-        if (routers.size() > 0) {
+        if (CollectionUtils.isNotEmpty(routers)) {
             return routers;
         }
 
@@ -712,4 +713,4 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
         }
         return result;
     }
-}
\ No newline at end of file
+}
