@@ -148,8 +148,13 @@ public class DirectNetworkGuru extends AdapterBase implements NetworkGuru {
                 && offering.getGuestType() == GuestType.Shared
                 && !_ntwkOfferingSrvcDao.isProviderForNetworkOffering(offering.getId(), Network.Provider.NiciraNvp)) {
             return true;
+        } else if (dc.getNetworkType() == NetworkType.Advanced
+                && offering.getGuestType() == GuestType.Shared
+                && ! _ntwkOfferingSrvcDao.isProviderForNetworkOffering(offering.getId(), Network.Provider.Ovs)
+                && physnet.getIsolationMethods().contains("GRE")) {
+            return true;
         } else {
-            s_logger.trace("We only take care of Guest networks of type " + GuestType.Shared);
+            s_logger.trace("We only take care of Shared Guest networks without Ovs or NiciraNvp provider");
             return false;
         }
     }
@@ -205,6 +210,13 @@ public class DirectNetworkGuru extends AdapterBase implements NetworkGuru {
             if (userSpecified.getPvlanType() != null) {
                 config.setPvlanType(userSpecified.getPvlanType());
             }
+
+            if (userSpecified.getRouterIp() != null) {
+                config.setRouterIp(userSpecified.getRouterIp());
+            }
+            if (userSpecified.getRouterIpv6() != null) {
+                config.setRouterIpv6(userSpecified.getRouterIpv6());
+            }
         }
 
         boolean isSecurityGroupEnabled = _networkModel.areServicesSupportedByNetworkOffering(offering.getId(), Service.SecurityGroup);
