@@ -543,7 +543,7 @@ setup_system_rfc1918_internal() {
   public_ip=`getPublicIp`
   echo "$public_ip" | grep -E "^((127\.)|(10\.)|(172\.1[6-9]\.)|(172\.2[0-9]\.)|(172\.3[0-1]\.)|(192\.168\.))"
   if [ "$?" == "0" ]; then
-     log_it "Not setting up route of RFC1918 space to $LOCAL_GW befause $public_ip is RFC1918."
+     log_it "Not setting up route of RFC1918 space to $LOCAL_GW because $public_ip is RFC1918."
   else
      log_it "Setting up route of RFC1918 space to $LOCAL_GW"
      # Setup general route for RFC 1918 space, as otherwise it will be sent to
@@ -759,6 +759,9 @@ parse_cmd_line() {
         ntpserverlist)
             export NTP_SERVER_LIST=$VALUE
             ;;
+        authorized_key)
+            export AUTHORIZED_KEYS=$VALUE
+            ;;
       esac
   done
   echo -e "\n\t}\n}" >> ${CHEF_TMP_FILE}
@@ -767,6 +770,17 @@ parse_cmd_line() {
     mv ${CHEF_TMP_FILE} /var/cache/cloud/cmd_line.json
   fi
 
+  TMP_KEY_PATH=/tmp/.auth_key
+  AUTHORIZED_KEYS_PATH=/root/.ssh/authorized_keys
+  if [ ! -z "$AUTHORIZED_KEYS" ]
+  then
+    echo "$AUTHORIZED_KEYS" > $TMP_KEY_PATH
+    base64Val=$(base64 -d $TMP_KEY_PATH)
+    echo "$base64Val" > $AUTHORIZED_KEYS_PATH
+    chmod go-rwx $AUTHORIZED_KEYS_PATH
+    rm -rf $TMP_KEY_PATH
+  fi
+
   [ $ETH0_IP ] && export LOCAL_ADDRS=$ETH0_IP
   [ $ETH0_IP6 ] && export LOCAL_ADDRS=$ETH0_IP6
   [ $ETH0_IP ] && [ $ETH0_IP6 ] && export LOCAL_ADDRS="$ETH0_IP,$ETH0_IP6"
