@@ -18,7 +18,8 @@
 """
 #Import Local Modules
 from nose.plugins.attrib import attr
-from marvin.cloudstackTestCase import cloudstackTestCase, unittest
+from marvin.cloudstackTestCase import cloudstackTestCase
+import unittest
 from marvin.cloudstackAPI import deleteVolume
 from marvin.lib.utils import (cleanup_resources, validateList)
 from marvin.lib.base import (Project,
@@ -2026,4 +2027,4 @@ class TestVMSnapshotUsage(cloudstackTestCase):
                             1,
                             "Check VM.SNAPSHOT.DELETE in events table"
                         )
-        return
\ No newline at end of file
+        return
