@@ -19,7 +19,7 @@ import Vuex from 'vuex'
 
 const mockStore = {
   state: {},
-  mock: (state, actions) => {
+  mock: (state, actions, mutations) => {
     mockStore.state = {
       app: {
         device: 'desktop'
@@ -27,11 +27,16 @@ const mockStore = {
       user: {},
       permission: {}
     }
+    mockStore.mutations = {}
 
     if (state && Object.keys(state).length > 0) {
       mockStore.state = { ...mockStore.state, ...state }
     }
 
+    if (mutations && Object.keys(mutations).length > 0) {
+      mockStore.mutations = { ...mockStore.mutations, ...mutations }
+    }
+
     if (!actions) {
       actions = {}
     }
@@ -40,9 +45,12 @@ const mockStore = {
       state: mockStore.state,
       getters: {
         apis: () => mockStore.state.user.apis,
-        userInfo: () => mockStore.state.user.info
+        userInfo: () => mockStore.state.user.info,
+        headerNotices: () => mockStore.state.user.headerNotices,
+        defaultListViewPageSize: () => mockStore.state.user.defaultListViewPageSize
       },
-      actions
+      actions,
+      mutations
     })
   }
 }
